rai\_toolbox.augmentations.fourier.generate\_fourier\_bases
===========================================================

.. currentmodule:: rai_toolbox.augmentations.fourier

.. autofunction:: generate_fourier_bases